--- a/mercurial/commands.py Thu Jul 11 19:28:54 2013 -0500
+++ b/mercurial/commands.py Thu Jul 11 19:29:23 2013 -0500
@@ -5692,7 +5692,7 @@
] + templateopts,
_('[-p] [-g]'))
def tip(ui, repo, **opts):
"""show the tip revision
The tip revision (usually just called the tip) is the changeset
most recently added to the repository (and therefore the most
@@ -5703,6 +5703,8 @@
that repository becomes the current tip. The "tip" tag is special
and cannot be renamed or assigned to a different changeset.
+ This command is deprecated, please use :hg:`heads` instead.
+
Returns 0 on success.
"""
displayer = cmdutil.show_changeset(ui, repo, opts)
@@ -5692,7 +5692,7 @@
_('[-p] [-g]'))
def tip(ui, repo, **opts):
- """show the tip revision
+ """show the tip revision (DEPRECATED)
The tip revision (usually just called the tip) is the changeset
most recently added to the repository (and therefore the most